//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Element/PolarizerPair.cpp
//! @brief     Implements class PolarizerPair.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Base/Element/PolarizerPair.h"

// corresponds to completely unpolarized beam and the absence of spin selection in the analyzer
PolarizerPair::PolarizerPair()
    : m_polpair(Eigen::Matrix2cd::Identity() / 2.0)
    , m_analyzer_operator(Eigen::Matrix2cd::Identity())
{
}

PolarizerPair::PolarizerPair(const Eigen::Matrix2cd& polarization, const Eigen::Matrix2cd& analyzer)
    : m_polpair(polarization), m_analyzer_operator(analyzer)
{
}

void PolarizerPair::swapContent(PolarizerPair& other)
{
    std::swap(m_polpair, other.m_polpair);
    std::swap(m_analyzer_operator, other.m_analyzer_operator);
}
