//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Vector/WavevectorInfo.h
//! @brief     Defines WavevectorInfo.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_BASE_VECTOR_WAVEVECTORINFO_H
#define BORNAGAIN_BASE_VECTOR_WAVEVECTORINFO_H

#include "Base/Vector/Vectors3D.h"

class Transform3D;

//! Holds all wavevector information relevant for calculating form factors.

class WavevectorInfo {
public:
    static WavevectorInfo makeZeroQ();
    WavevectorInfo(cvector_t ki, cvector_t kf, double wavelength);
    WavevectorInfo(kvector_t ki, kvector_t kf, double wavelength);

    WavevectorInfo transformed(const Transform3D& transform) const;
    cvector_t getKi() const { return m_ki; }
    cvector_t getKf() const { return m_kf; }
    cvector_t getQ() const { return m_ki - m_kf; }
    double vacuumLambda() const { return m_vacuum_wavelength; }

private:
    cvector_t m_ki;
    cvector_t m_kf;
    double m_vacuum_wavelength;
};

#endif // BORNAGAIN_BASE_VECTOR_WAVEVECTORINFO_H
#endif // USER_API
