//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Pol/PolFilter.h
//! @brief     Defines class DetectionProperties.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_DEVICE_POL_POLFILTER_H
#define BORNAGAIN_DEVICE_POL_POLFILTER_H

#include "Base/Vector/EigenCore.h"
#include "Base/Vector/Vectors3D.h"
#include "Param/Node/INode.h"

//! Detector properties (efficiency, transmission).
//! @ingroup detector

class PolFilter : public INode {
public:
    PolFilter(kvector_t direction, double efficiency, double total_transmission);
    PolFilter();
    PolFilter(const PolFilter& other);

    virtual ~PolFilter() = default;

    //! Sets the polarization analyzer characteristics of the detector
    void setDirEffTra(const kvector_t direction, double efficiency, double total_transmission);

    //! Return the polarization density matrix (in spin basis along z-axis)
    Eigen::Matrix2cd analyzerOperator() const;

    //! Retrieve the analyzer characteristics
    kvector_t polDirection() const;
    double polEfficiency() const; //!< will always return positive value
    double totalTransmission() const;

    void accept(INodeVisitor* visitor) const override { visitor->visit(this); }

private:
    //! Verify if the given analyzer properties are physical
    bool check(const kvector_t direction, double efficiency, double total_transmission) const;

    kvector_t m_direction;       //!< direction of polarization analysis
    double m_efficiency;         //!< efficiency of polarization analysis
    double m_total_transmission; //!< total transmission of polarization analysis
};

#endif // BORNAGAIN_DEVICE_POL_POLFILTER_H
#endif // USER_API
