//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Views/widgetbox/widgetboxtreewidget.h
//! @brief     Defines class WidgetBoxTreeWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEWS_WIDGETBOX_WIDGETBOXTREEWIDGET_H
#define BORNAGAIN_GUI_VIEWS_WIDGETBOX_WIDGETBOXTREEWIDGET_H

#include <QTreeWidget>

class WidgetBoxCategoryListView;

//! A tree of categories
class WidgetBoxTreeWidget : public QTreeWidget {
    Q_OBJECT

public:
    explicit WidgetBoxTreeWidget(QWidget* parent = 0);

    //! Adds a group at the end of the list
    void addGroup(const QString& title);

    //! Adds an entry in the last group
    void addEntry(const QString& title, const QIcon& icon, const QString& className,
                  const QString& tooltip);

signals:
    void pressed(const QString name, const QString dom_xml, const QPoint& global_mouse_pos);

public slots:
    void filter(const QString&);

protected:
    virtual void contextMenuEvent(QContextMenuEvent* e);
    virtual void resizeEvent(QResizeEvent* e);

private slots:
    void handleMousePress(QTreeWidgetItem* item);
    void slotListMode();
    void slotIconMode();

private:
    WidgetBoxCategoryListView* addCategoryView(QTreeWidgetItem* parent, bool iconMode);
    WidgetBoxCategoryListView* categoryViewAt(int idx) const;
    void adjustSubListSize(QTreeWidgetItem* cat_item);
    void updateViewMode();

private:
    bool m_iconMode;
};

#endif // BORNAGAIN_GUI_VIEWS_WIDGETBOX_WIDGETBOXTREEWIDGET_H
