//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Param/Base/IParametric.cpp
//! @brief     Implements interface IParametric.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Param/Base/IParametric.h"
#include "Base/Utils/StringUtils.h"
#include "Fit/Param/RealLimits.h"
#include <iostream>
#include <sstream>
#include <stdexcept>

IParametric::IParametric(const std::string& name) : m_name{name} {}

IParametric::~IParametric() = default;

void IParametric::checkLimits(const std::string& name, const double value,
                              const RealLimits& limits) const
{
    if (!limits.isInRange(value)) {
        std::ostringstream message;
        message << "Cannot initialize parameter " << name << " with value " << value
                << ": out of bounds [" << limits << "]\n";
        throw std::runtime_error(message.str());
    }
}
