//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Param/Base/IParametric.h
//! @brief     Defines interface IParametric.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef USER_API
#ifndef BORNAGAIN_PARAM_BASE_IPARAMETRIC_H
#define BORNAGAIN_PARAM_BASE_IPARAMETRIC_H

#include <string>

class RealLimits;

//! Originally managed registered parameters. Is somehow a left-over of the big refactoring when
//! these parameters have been taken out. Maybe could be refactored to be put into IComponent.

class IParametric {
public:
    IParametric(const std::string& name = "");
    virtual ~IParametric();

    IParametric& operator=(const IParametric& other) = delete;

    const std::string& getName() const { return m_name; }

    //! Action to be taken in inherited class when a value has changed. Formerly this was also
    //! called when a change via registered parameter took place. This is now obsolete, but the
    //! onChange() call is still relevant for calculations when a value is changed by different
    //! means (e.g. after initialization).
    virtual void onChange() {}

protected:
    void setName(const std::string& name) { m_name = name; }

    //! Check a certain value against limits.
    //! Throws if not within the limits.
    //! Name is only for exception message.
    void checkLimits(const std::string& name, const double value, const RealLimits& limits) const;

private:
    std::string m_name;
};

#endif // BORNAGAIN_PARAM_BASE_IPARAMETRIC_H
#endif // USER_API
